@@ -149,20 +149,13 @@ def worms(obis: pd.DataFrame) -> pd.DataFrame:
 
     # link with mrgid using manual xlsx file
     link_df = read_gisd_worms_link()
-    link_df.dropna(subset=["MRGID"], inplace=True)
+    link_df.dropna(subset=["MRGID", "ECO_CODE_X"], inplace=True)
+    link_df = link_df[link_df.ECO_CODE_X != '-']
     link_df.loc[:, "MRGID"] = link_df["MRGID"].astype("int64")
-
     link_df.loc[:, "ECO_CODE_X"] = link_df["ECO_CODE_X"].astype("str")
-    df_split = pd.concat(
-        [
-            pd.Series(row["MRGID"], row["ECO_CODE_X"].split(","))
-            for _, row in link_df.iterrows()
-        ]
-    ).reset_index()
-    df_split.columns = ["ECO_CODE", "MRGID"]
-
-    df_all = link_df.merge(df_split, on="MRGID")
-    df_all.drop(["ECO_CODE_X"], axis=1, inplace=True)
+    link_df['ECO_CODE_X'] = link_df.ECO_CODE_X.str.split(',')
+    df_all = link_df.explode('ECO_CODE_X')
+    df_all = link_df.rename(columns={"ECO_CODE_X": "ECO_CODE"})
 
     link_manfile = df_all[(df_all["Source"] == "WoRMS") & (df_all["Shapefile"] == 0)]
     link_manfile = link_manfile[["MRGID", "ECO_CODE"]]
@@ -175,14 +168,15 @@ def worms(obis: pd.DataFrame) -> pd.DataFrame:
     df_worms_link_man.replace("nan", np.nan, inplace=True)
     df_worms_link_man["ECO_CODE"].replace("-", np.nan, inplace=True)
     df_worms_link_man.dropna(subset=["ECO_CODE"], inplace=True)
-    df_worms_link_man.loc[:, "ECO_CODE"] = df_worms_link_man["ECO_CODE"].astype("int64")
 
     df_meow = pd.DataFrame(read_shapefile(ShapeFiles.MEOW_ECOS))
     df_meow = df_meow[["ECO_CODE_X", "ECOREGION", "geometry"]]
     df_meow.loc[:, "ECO_CODE"] = df_meow["ECO_CODE_X"]
     df_meow.drop("ECO_CODE_X", axis=1, inplace=True)
     df_meow.loc[:, "ECO_CODE"] = df_meow["ECO_CODE"].astype("int64")
-    df_worms_link_man = df_worms_link_man.merge(df_meow, on="ECO_CODE")
+    df_tmp = df_worms_link_man.explode('ECO_CODE')
+    df_tmp['ECO_CODE'] = df_tmp['ECO_CODE'].astype('int64')
+    df_worms_link_man = pd.merge(df_tmp, df_meow, how='inner', on="ECO_CODE")
 
     # link with mrgid using other shapefiles
     df_eco_mrgid = eco_mrgid_link()
