@@ -21,7 +21,7 @@ More about data processing can be found at README.md and documentation
 
 import logging
 import warnings
-from typing import List, Union
+from typing import Union
 from pathlib import Path
 
 import matplotlib.pyplot as plt
@@ -31,7 +31,7 @@ from matplotlib.patches import Polygon
 
 import geopandas as gpd
 import numpy as np
-from marinvaders.api_calls import request_obis
+from marinvaders.api_calls import request_obis, obis_taxon
 from marinvaders.alien_observation import observations
 from marinvaders.readers import ShapeFiles, read_shapefile, read_redlist
 
@@ -51,6 +51,8 @@ logging.basicConfig(
 PUBLIC_HEADERS = [
     "aphiaID",
     "species",
+    "scientificName",
+    "acceptedNameUsage",
     "ECOREGION",
     "ECO_CODE",
     "establishmentMeans",
@@ -196,7 +198,7 @@ class Species:
             )
         self.all_occurrences: pd.DataFrame = self._create_all_occurrences(
             gisd_file=gisd_file
-        )[PUBLIC_HEADERS]
+        )
 
         self.reported_as_alien: pd.DataFrame = self.all_occurrences[
             self.all_occurrences.establishmentMeans == "Alien"
@@ -258,9 +260,13 @@ class Species:
         df = df.sort_values(by=["establishmentMeans"], na_position="last")
         df.drop_duplicates("ECO_CODE", inplace=True, keep="first")
         df["ECO_CODE"] = df["ECO_CODE"].astype("int64")
+        df["aphiaID"] = df["aphiaID"].astype("int64")
         df = df.drop(["index"], axis=1)
+        obis_extra_fields = obis_taxon(df.aphiaID.unique())
 
-        return df
+        df = df.merge(obis_extra_fields, on="aphiaID", how="left")
+
+        return df[PUBLIC_HEADERS]
 
     def plot(self, show: bool = True):
         """
@@ -382,7 +388,9 @@ class MarineLife(object):
         """
         self.eco_code: int = eco_code
         # All species from obis which are present in the selected eco-region
-        self._obis: pd.DataFrame = _get_obis(eco_code=eco_code)
+        _obis = _get_obis(eco_code=eco_code)
+        extra_obis_fields = obis_taxon(_obis.aphiaID.unique())
+        self._obis: pd.DataFrame = _obis.merge(extra_obis_fields, on="aphiaID", how="left")
         # All species in other db (WoRMs, GISD, NatCon)
         self._alien_observations: pd.DataFrame = observations(
             self._obis, gisd_file=gisd_file
@@ -440,19 +448,27 @@ class MarineLife(object):
         pd.DataFrame
             aliens species
         """
-        return self._alien_observations[
+        aliens = self._alien_observations[
             self._alien_observations["ECO_CODE"] == self.eco_code
         ].reset_index(drop=True)
+        if aliens.empty:
+            return pd.DataFrame()
+        extra_obis_fields = obis_taxon(aliens.aphiaID.unique())
+        df = aliens.merge(extra_obis_fields, on="aphiaID", how="left")
+
+        df['scientificName'] = df['scientificName_x']
+        df['acceptedNameUsage'] = df['acceptedNameUsage_x']
+
+        return df[PUBLIC_HEADERS]
 
     @property
-    def all_species(self) -> List[str]:
+    def all_species(self) -> pd.DataFrame:
         """
         List of all unique species.
 
         Returns
         -------
-        list
-            species names
+        pandas DataFrame
         """
         df_alien_observations = self._alien_observations[
             self._alien_observations["ECO_CODE"] == self.eco_code
@@ -460,13 +476,22 @@ class MarineLife(object):
         df_obis = self._obis[self._obis["ECO_CODE"] == self.eco_code].reset_index(
             drop=True
         )
-
-        df_merged = pd.concat([df_alien_observations, df_obis]).sort_values(
-            by=["establishmentMeans"], na_position="last"
-        )
+        try:
+            df_merged = pd.concat([df_alien_observations, df_obis]).sort_values(
+                by=["establishmentMeans"], na_position="last"
+            )
+        except Exception as e:
+            logging.error(f"MarineLife concatinating obis and aliens failed with: {e}")
+            df_merged = df_obis
         df_merged.drop_duplicates("aphiaID", inplace=True, keep="first")
+        extra_obis_fields = obis_taxon(df_merged.aphiaID.unique())
+        df = df_merged.merge(
+            extra_obis_fields, on="aphiaID", how="left"
+        )
+        df['scientificName'] = df['scientificName_x']
+        df['acceptedNameUsage'] = df['acceptedNameUsage_x']
 
-        return df_merged[PUBLIC_HEADERS]
+        return df[["aphiaID", "species", "scientificName", "acceptedNameUsage", "ECO_CODE"]]
 
 
 def plot(eco_code, show: bool = True):
