@@ -136,7 +136,7 @@ def eco_mrgid_link() -> pd.DataFrame:
     pd.DataFrame
         eco-region code linked to MRGID
     """
-    df = pd.read_hdf(os.path.join(data_path(), "eco_mrgid.h5"))
+    df = pd.read_csv(os.path.join(data_path(), "eco_mrgid.csv"))
     df.loc[:, "MRGID"] = df["MRGID"].astype("int64")
 
     return df
