@@ -70,6 +70,9 @@ def test_species_class():
     assert ds.reported_as_alien.ECO_CODE.dtype == "int64"
     assert ds.all_occurrences.ECO_CODE.dtype == "int64"
 
+    assert "scientificName" in ds.all_occurrences.columns
+    assert "acceptedNameUsage" in ds.all_occurrences.columns
+
 
 def test_marine_life_class():
     """
@@ -84,6 +87,8 @@ def test_marine_life_class():
     assert cocos.all_species.aphiaID.dtype == "int64"
     assert cocos.alien_species.ECO_CODE.dtype == "int64"
     assert cocos.all_species.ECO_CODE.dtype == "int64"
+    assert "scientificName" in cocos.alien_species.columns
+    assert "acceptedNameUsage" in cocos.alien_species.columns
 
 
 def test_big_region_obis_api():
